==> jc-1.4.0.tar.gz: javax/swing/JToggleButton__24AccessibleJToggleButton.h <==
// public class javax.swing.JToggleButton$AccessibleJToggleButton

// class file dependencies
// @dep_class 61b24c22f38bff85 java_awt_Component__24AccessibleAWTComponent
// @dep_class 6d5f0a9d86bc5fc4 java_awt_Container__24AccessibleAWTContainer
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext
// @dep_class 3f25717f6c53c837 javax_swing_AbstractButton__24AccessibleAbstractButton
// @dep_class 32f620e3c8c75689 javax_swing_JComponent__24AccessibleJComponent
// @dep_class 97d486940e7264b javax_swing_JToggleButton__24AccessibleJToggleButton

// header file dependencies
// @dep_header javax_swing_AbstractButton__24AccessibleAbstractButton

#include "javax/swing/AbstractButton__24AccessibleAbstractButton.h"

#ifndef _JC_javax_swing_JToggleButton__24AccessibleJToggleButton_H_
#define _JC_javax_swing_JToggleButton__24AccessibleJToggleButton_H_

// Forward structure declarations
struct _jc_java_awt_event_ItemEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_accessibility_AccessibleRole$object;
struct _jc_javax_swing_JToggleButton$object;

// Typedefs
typedef struct _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$sub_refs	_jc_javax_swing_JToggleButton__24AccessibleJToggleButton$sub_refs;
typedef struct _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$sub_nonrefs	_jc_javax_swing_JToggleButton__24AccessibleJToggleButton$sub_nonrefs;
typedef struct _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$refs	_jc_javax_swing_JToggleButton__24AccessibleJToggleButton$refs;
typedef struct _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$nonrefs	_jc_javax_swing_JToggleButton__24AccessibleJToggleButton$nonrefs;
typedef struct _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$object	_jc_javax_swing_JToggleButton__24AccessibleJToggleButton$object;

typedef const struct _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$vmethods	_jc_javax_swing_JToggleButton__24AccessibleJToggleButton$vmethods;
typedef const struct _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$vtable	_jc_javax_swing_JToggleButton__24AccessibleJToggleButton$vtable;
typedef const struct _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$vtype	_jc_javax_swing_JToggleButton__24AccessibleJToggleButton$vtype;

// Constructors
extern void _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$method$_init$4f38cdbbc95a120f(_jc_env *, struct _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$object *, struct _jc_javax_swing_JToggleButton$object *);

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleRole$object *_jc_javax_swing_JToggleButton__24AccessibleJToggleButton$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *, struct _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$object *);
extern void _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$method$itemStateChanged$e00fff457ef1ce53(_jc_env *, struct _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$object *, struct _jc_java_awt_event_ItemEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$method_info$getAccessibleRole$eaa05a502d0ede18;
extern _jc_method _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$method_info$itemStateChanged$e00fff457ef1ce53;

// Virtual methods structure
struct _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$vmethods {
	struct _jc_javax_accessibility_AccessibleRole$object	*(*getAccessibleRole$eaa05a502d0ede18)(_jc_env *, struct _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$object *);
	void	(*itemStateChanged$e00fff457ef1ce53)(_jc_env *, struct _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$object *, struct _jc_java_awt_event_ItemEvent$object *);
};

// Vtable
struct _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_Component__24AccessibleAWTComponent$vmethods	java_awt_Component__24AccessibleAWTComponent;
	_jc_java_awt_Container__24AccessibleAWTContainer$vmethods	java_awt_Container__24AccessibleAWTContainer;
	_jc_javax_swing_JComponent__24AccessibleJComponent$vmethods	javax_swing_JComponent__24AccessibleJComponent;
	_jc_javax_swing_AbstractButton__24AccessibleAbstractButton$vmethods	javax_swing_AbstractButton__24AccessibleAbstractButton;
	_jc_javax_swing_JToggleButton__24AccessibleJToggleButton$vmethods	javax_swing_JToggleButton__24AccessibleJToggleButton;
};

// Vtype
struct _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$vtype {
	_jc_type			type;
	_jc_javax_swing_JToggleButton__24AccessibleJToggleButton$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$sub_refs {
	struct _jc_javax_swing_JToggleButton$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$refs {
    _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$sub_refs	javax_swing_JToggleButton__24AccessibleJToggleButton;
    _jc_javax_swing_AbstractButton__24AccessibleAbstractButton$sub_refs	javax_swing_AbstractButton__24AccessibleAbstractButton;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_refs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_refs	java_awt_Container__24AccessibleAWTContainer;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_refs	java_awt_Component__24AccessibleAWTComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_nonrefs	java_awt_Container__24AccessibleAWTContainer;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_nonrefs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_javax_swing_AbstractButton__24AccessibleAbstractButton$sub_nonrefs	javax_swing_AbstractButton__24AccessibleAbstractButton;
    _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$sub_nonrefs	javax_swing_JToggleButton__24AccessibleJToggleButton;
};

// Object instance structure
struct _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$object {
	_jc_javax_swing_JToggleButton__24AccessibleJToggleButton$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JToggleButton__24AccessibleJToggleButton$vtype	*vtype;
	_jc_javax_swing_JToggleButton__24AccessibleJToggleButton$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$vtype _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JToggleButton__24AccessibleJToggleButton, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$class_object;

#endif	/* _JC_javax_swing_JToggleButton__24AccessibleJToggleButton_H_ */

==> jc-1.4.5.tar.gz: javax/swing/JToggleButton__24AccessibleJToggleButton.h <==
// public class javax.swing.JToggleButton$AccessibleJToggleButton

// class file dependencies
// @dep_class e1ad6f3c35669e42 java_awt_Component__24AccessibleAWTComponent
// @dep_class 6d5f0a9d86bc5fc4 java_awt_Container__24AccessibleAWTContainer
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext
// @dep_class 3f25717f6c53c837 javax_swing_AbstractButton__24AccessibleAbstractButton
// @dep_class 32f620e3c8c75689 javax_swing_JComponent__24AccessibleJComponent
// @dep_class 97d486940e7264b javax_swing_JToggleButton__24AccessibleJToggleButton

// header file dependencies
// @dep_header javax_swing_AbstractButton__24AccessibleAbstractButton

#include "javax/swing/AbstractButton__24AccessibleAbstractButton.h"

#ifndef _JC_javax_swing_JToggleButton__24AccessibleJToggleButton_H_
#define _JC_javax_swing_JToggleButton__24AccessibleJToggleButton_H_

// Forward structure declarations
struct _jc_java_awt_event_ItemEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_accessibility_AccessibleRole$object;
struct _jc_javax_swing_JToggleButton$object;

// Typedefs
typedef struct _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$sub_refs	_jc_javax_swing_JToggleButton__24AccessibleJToggleButton$sub_refs;
typedef struct _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$sub_nonrefs	_jc_javax_swing_JToggleButton__24AccessibleJToggleButton$sub_nonrefs;
typedef struct _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$refs	_jc_javax_swing_JToggleButton__24AccessibleJToggleButton$refs;
typedef struct _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$nonrefs	_jc_javax_swing_JToggleButton__24AccessibleJToggleButton$nonrefs;
typedef struct _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$object	_jc_javax_swing_JToggleButton__24AccessibleJToggleButton$object;

typedef const struct _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$vmethods	_jc_javax_swing_JToggleButton__24AccessibleJToggleButton$vmethods;
typedef const struct _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$vtable	_jc_javax_swing_JToggleButton__24AccessibleJToggleButton$vtable;
typedef const struct _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$vtype	_jc_javax_swing_JToggleButton__24AccessibleJToggleButton$vtype;

// Constructors
extern void _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$method$_init$4f38cdbbc95a120f(_jc_env *, struct _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$object *, struct _jc_javax_swing_JToggleButton$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleRole$object *_jc_javax_swing_JToggleButton__24AccessibleJToggleButton$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *, struct _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$method$itemStateChanged$e00fff457ef1ce53(_jc_env *, struct _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$object *, struct _jc_java_awt_event_ItemEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$method_info$getAccessibleRole$eaa05a502d0ede18;
extern _jc_method _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$method_info$itemStateChanged$e00fff457ef1ce53;

// Virtual methods structure
struct _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$vmethods {
	struct _jc_javax_accessibility_AccessibleRole$object	*(*getAccessibleRole$eaa05a502d0ede18)(_jc_env *, struct _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$object *) _JC_JCNI_ATTR;
	void	(*itemStateChanged$e00fff457ef1ce53)(_jc_env *, struct _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$object *, struct _jc_java_awt_event_ItemEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_Component__24AccessibleAWTComponent$vmethods	java_awt_Component__24AccessibleAWTComponent;
	_jc_java_awt_Container__24AccessibleAWTContainer$vmethods	java_awt_Container__24AccessibleAWTContainer;
	_jc_javax_swing_JComponent__24AccessibleJComponent$vmethods	javax_swing_JComponent__24AccessibleJComponent;
	_jc_javax_swing_AbstractButton__24AccessibleAbstractButton$vmethods	javax_swing_AbstractButton__24AccessibleAbstractButton;
	_jc_javax_swing_JToggleButton__24AccessibleJToggleButton$vmethods	javax_swing_JToggleButton__24AccessibleJToggleButton;
};

// Vtype
struct _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$vtype {
	_jc_type			type;
	_jc_javax_swing_JToggleButton__24AccessibleJToggleButton$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$sub_refs {
	struct _jc_javax_swing_JToggleButton$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$refs {
    _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$sub_refs	javax_swing_JToggleButton__24AccessibleJToggleButton;
    _jc_javax_swing_AbstractButton__24AccessibleAbstractButton$sub_refs	javax_swing_AbstractButton__24AccessibleAbstractButton;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_refs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_refs	java_awt_Container__24AccessibleAWTContainer;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_refs	java_awt_Component__24AccessibleAWTComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_nonrefs	java_awt_Container__24AccessibleAWTContainer;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_nonrefs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_javax_swing_AbstractButton__24AccessibleAbstractButton$sub_nonrefs	javax_swing_AbstractButton__24AccessibleAbstractButton;
    _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$sub_nonrefs	javax_swing_JToggleButton__24AccessibleJToggleButton;
};

// Object instance structure
struct _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$object {
	_jc_javax_swing_JToggleButton__24AccessibleJToggleButton$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JToggleButton__24AccessibleJToggleButton$vtype	*vtype;
	_jc_javax_swing_JToggleButton__24AccessibleJToggleButton$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$vtype _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JToggleButton__24AccessibleJToggleButton, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JToggleButton__24AccessibleJToggleButton$class_object;

#endif	/* _JC_javax_swing_JToggleButton__24AccessibleJToggleButton_H_ */
